@@ -48,11 +48,11 @@ class TokenValidator:
 
         if self._public_key is None:
             self._public_key = await self.context.auth_server_connector.get_public_key()
-
+        logger.debug(f"Decoding jwt using public key: {self._public_key}")
         try:
             payload = jwt.decode(token, self._public_key, algorithms=[self._SIGNATURE_ALGORITHM])
-        except DecodeError:
-            raise InvalidTokenError("Invalid token")
+        except DecodeError as er:
+            raise InvalidTokenError(f"Invalid token, parent Exception: {repr(er)}")
         except ExpiredSignatureError:
             raise ExpiredTokenError(f"{TokenType.ACCESS_TOKEN} lifetime ended")
 
